# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeRequest(Model):
    """MeRequest.

    :param preference:
    :type preference: ~energycap.sdk.models.PreferenceRequest
    :param full_name: User's full name <span
     class='property-internal'>Required (defined)</span>
    :type full_name: str
    :param email: User's email address <span
     class='property-internal'>Required (defined)</span>
    :type email: str
    """

    _validation = {
        'full_name': {'max_length': 32},
        'email': {'max_length': 128},
    }

    _attribute_map = {
        'preference': {'key': 'preference', 'type': 'PreferenceRequest'},
        'full_name': {'key': 'fullName', 'type': 'str'},
        'email': {'key': 'email', 'type': 'str'},
    }

    def __init__(self, preference=None, full_name=None, email=None):
        super(MeRequest, self).__init__()
        self.preference = preference
        self.full_name = full_name
        self.email = email



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterSerialNumberHistoryChild(Model):
    """MeterSerialNumberHistoryChild.

    :param previous_serial_number: Previous serial number of the meter
    :type previous_serial_number: str
    :param serial_number_change_date: Date that serial number changed
    :type serial_number_change_date: datetime
    """

    _attribute_map = {
        'previous_serial_number': {'key': 'previousSerialNumber', 'type': 'str'},
        'serial_number_change_date': {'key': 'serialNumberChangeDate', 'type': 'iso-8601'},
    }

    def __init__(self, previous_serial_number=None, serial_number_change_date=None):
        super(MeterSerialNumberHistoryChild, self).__init__()
        self.previous_serial_number = previous_serial_number
        self.serial_number_change_date = serial_number_change_date



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ListActionApprove(Model):
    """ListActionApprove.

    :param approve:  <span class='property-internal'>Required (defined)</span>
    :type approve: bool
    """

    _attribute_map = {
        'approve': {'key': 'approve', 'type': 'bool'},
    }

    def __init__(self, approve=None):
        super(ListActionApprove, self).__init__()
        self.approve = approve



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class LicenseFeatures(Model):
    """LicenseFeatures.

    :param accounting_export: Whether accounting export is available on the
     user's the license.
    :type accounting_export: bool
    :param bill_accruals: Whether bill accruals are available on the user's
     license.
    :type bill_accruals: bool
    :param chargebacks: Whether chargebacks are available on the user's
     license.
    :type chargebacks: bool
    :param cost_avoidance: Whether cost avoidance is available on the user's
     license.
    :type cost_avoidance: bool
    :param custom_benchmarks: Whether custom benchmarks are available on the
     user's license.
    :type custom_benchmarks: bool
    :param interval_data_analysis: Whether interval data analysis is available
     on the user's license.
    :type interval_data_analysis: bool
    :param report_designer: Whether report designer is available on the user's
     license.
    :type report_designer: bool
    """

    _attribute_map = {
        'accounting_export': {'key': 'accountingExport', 'type': 'bool'},
        'bill_accruals': {'key': 'billAccruals', 'type': 'bool'},
        'chargebacks': {'key': 'chargebacks', 'type': 'bool'},
        'cost_avoidance': {'key': 'costAvoidance', 'type': 'bool'},
        'custom_benchmarks': {'key': 'customBenchmarks', 'type': 'bool'},
        'interval_data_analysis': {'key': 'intervalDataAnalysis', 'type': 'bool'},
        'report_designer': {'key': 'reportDesigner', 'type': 'bool'},
    }

    def __init__(self, accounting_export=None, bill_accruals=None, chargebacks=None, cost_avoidance=None, custom_benchmarks=None, interval_data_analysis=None, report_designer=None):
        super(LicenseFeatures, self).__init__()
        self.accounting_export = accounting_export
        self.bill_accruals = bill_accruals
        self.chargebacks = chargebacks
        self.cost_avoidance = cost_avoidance
        self.custom_benchmarks = custom_benchmarks
        self.interval_data_analysis = interval_data_analysis
        self.report_designer = report_designer



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillHeaderUpdateEndDateChild(Model):
    """End Date.

    :param end_date:  <span class='property-internal'>Required when Update is
     set to True</span> <span class='property-internal'>Must be between
     12/31/1899 and 1/1/3000</span>
    :type end_date: datetime
    :param update: Indicates whether or not the header value is being updated
     <span class='property-internal'>Required</span>
    :type update: bool
    """

    _validation = {
        'update': {'required': True},
    }

    _attribute_map = {
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'update': {'key': 'update', 'type': 'bool'},
    }

    def __init__(self, update, end_date=None):
        super(BillHeaderUpdateEndDateChild, self).__init__()
        self.end_date = end_date
        self.update = update



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Country(Model):
    """Country.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar country_id:
    :vartype country_id: int
    :ivar name:
    :vartype name: str
    :ivar alpha2_code:
    :vartype alpha2_code: str
    :ivar possible_spellings:
    :vartype possible_spellings: list[str]
    """

    _validation = {
        'country_id': {'readonly': True},
        'name': {'readonly': True},
        'alpha2_code': {'readonly': True},
        'possible_spellings': {'readonly': True},
    }

    _attribute_map = {
        'country_id': {'key': 'countryId', 'type': 'int'},
        'name': {'key': 'name', 'type': 'str'},
        'alpha2_code': {'key': 'alpha2Code', 'type': 'str'},
        'possible_spellings': {'key': 'possibleSpellings', 'type': '[str]'},
    }

    def __init__(self):
        super(Country, self).__init__()
        self.country_id = None
        self.name = None
        self.alpha2_code = None
        self.possible_spellings = None



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CreateTemplateFromBill(Model):
    """CreateTemplateFromBill.

    :param template_code: The template code
     Always converted to uppercase <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type template_code: str
    :param note: The template note <span class='property-internal'>Must be
     between 0 and 255 characters</span>
    :type note: str
    """

    _validation = {
        'template_code': {'required': True, 'max_length': 32, 'min_length': 0},
        'note': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'template_code': {'key': 'templateCode', 'type': 'str'},
        'note': {'key': 'note', 'type': 'str'},
    }

    def __init__(self, template_code, note=None):
        super(CreateTemplateFromBill, self).__init__()
        self.template_code = template_code
        self.note = note



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SpecificReportResponse(Model):
    """SpecificReportResponse.

    :param specific_report_id: Unique identifier for the report
    :type specific_report_id: int
    :param base_report:
    :type base_report: ~energycap.sdk.models.ReportChild
    :param specific_report_code: Report code
    :type specific_report_code: str
    :param specific_report_info: Report name
    :type specific_report_info: str
    :param last_viewed: Last time this report was run
    :type last_viewed: datetime
    :param recommended: Indicates if this is a recommended report
    :type recommended: bool
    :param report_category:
    :type report_category: ~energycap.sdk.models.ReportCategoryChild
    :param description: The report description
    :type description: str
    :param visible: Indicates if this report is visible to the current user
    :type visible: bool
    :param shared: Indicates if this report is shared
    :type shared: bool
    :param user:
    :type user: ~energycap.sdk.models.UserChild
    :param subscription:
    :type subscription: ~energycap.sdk.models.ReportSubscriptionChild
    """

    _attribute_map = {
        'specific_report_id': {'key': 'specificReportId', 'type': 'int'},
        'base_report': {'key': 'baseReport', 'type': 'ReportChild'},
        'specific_report_code': {'key': 'specificReportCode', 'type': 'str'},
        'specific_report_info': {'key': 'specificReportInfo', 'type': 'str'},
        'last_viewed': {'key': 'lastViewed', 'type': 'iso-8601'},
        'recommended': {'key': 'recommended', 'type': 'bool'},
        'report_category': {'key': 'reportCategory', 'type': 'ReportCategoryChild'},
        'description': {'key': 'description', 'type': 'str'},
        'visible': {'key': 'visible', 'type': 'bool'},
        'shared': {'key': 'shared', 'type': 'bool'},
        'user': {'key': 'user', 'type': 'UserChild'},
        'subscription': {'key': 'subscription', 'type': 'ReportSubscriptionChild'},
    }

    def __init__(self, specific_report_id=None, base_report=None, specific_report_code=None, specific_report_info=None, last_viewed=None, recommended=None, report_category=None, description=None, visible=None, shared=None, user=None, subscription=None):
        super(SpecificReportResponse, self).__init__()
        self.specific_report_id = specific_report_id
        self.base_report = base_report
        self.specific_report_code = specific_report_code
        self.specific_report_info = specific_report_info
        self.last_viewed = last_viewed
        self.recommended = recommended
        self.report_category = report_category
        self.description = description
        self.visible = visible
        self.shared = shared
        self.user = user
        self.subscription = subscription



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterCategoryRequest(Model):
    """MeterCategoryRequest.

    :param meter_group_category_code: The meter category code <span
     class='property-internal'>Must be between 0 and 32 characters</span> <span
     class='property-internal'>Required</span>
    :type meter_group_category_code: str
    :param meter_group_category_info: The meter category info <span
     class='property-internal'>Must be between 0 and 32 characters</span> <span
     class='property-internal'>Required</span>
    :type meter_group_category_info: str
    """

    _validation = {
        'meter_group_category_code': {'required': True, 'max_length': 32, 'min_length': 0},
        'meter_group_category_info': {'required': True, 'max_length': 32, 'min_length': 0},
    }

    _attribute_map = {
        'meter_group_category_code': {'key': 'meterGroupCategoryCode', 'type': 'str'},
        'meter_group_category_info': {'key': 'meterGroupCategoryInfo', 'type': 'str'},
    }

    def __init__(self, meter_group_category_code, meter_group_category_info):
        super(MeterCategoryRequest, self).__init__()
        self.meter_group_category_code = meter_group_category_code
        self.meter_group_category_info = meter_group_category_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WebhookResponse(Model):
    """WebhookResponse.

    :param webhook_id: The identifier of the webhook
    :type webhook_id: int
    :param webhook_name: The name of the webhook
    :type webhook_name: str
    :param webhook_description: The description of the webhook
    :type webhook_description: str
    :param created_by:
    :type created_by: ~energycap.sdk.models.UserChild
    :param created_date: The date and time the webhook was created
    :type created_date: datetime
    :param mailing_list: List of email addresses. Each recipient in this list
     will receive an email when a webhook fails or gets disabled
    :type mailing_list: list[str]
    :param success_rate: The percentage of success for the webhook
    :type success_rate: float
    :param webhook_status: The activation status of the webhook
    :type webhook_status: str
    :param locked: Locked webhooks cannot be edited.
     Locked webhooks will also NOT be automatically disabled on 10 consecutive
     failures
    :type locked: bool
    :param url: The URL to be invoked by the webhook
    :type url: str
    :param secret: The encryption secret
    :type secret: str
    :param event_type:
    :type event_type: ~energycap.sdk.models.WebhookEventTypeChild
    """

    _attribute_map = {
        'webhook_id': {'key': 'webhookId', 'type': 'int'},
        'webhook_name': {'key': 'webhookName', 'type': 'str'},
        'webhook_description': {'key': 'webhookDescription', 'type': 'str'},
        'created_by': {'key': 'createdBy', 'type': 'UserChild'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
        'mailing_list': {'key': 'mailingList', 'type': '[str]'},
        'success_rate': {'key': 'successRate', 'type': 'float'},
        'webhook_status': {'key': 'webhookStatus', 'type': 'str'},
        'locked': {'key': 'locked', 'type': 'bool'},
        'url': {'key': 'url', 'type': 'str'},
        'secret': {'key': 'secret', 'type': 'str'},
        'event_type': {'key': 'eventType', 'type': 'WebhookEventTypeChild'},
    }

    def __init__(self, webhook_id=None, webhook_name=None, webhook_description=None, created_by=None, created_date=None, mailing_list=None, success_rate=None, webhook_status=None, locked=None, url=None, secret=None, event_type=None):
        super(WebhookResponse, self).__init__()
        self.webhook_id = webhook_id
        self.webhook_name = webhook_name
        self.webhook_description = webhook_description
        self.created_by = created_by
        self.created_date = created_date
        self.mailing_list = mailing_list
        self.success_rate = success_rate
        self.webhook_status = webhook_status
        self.locked = locked
        self.url = url
        self.secret = secret
        self.event_type = event_type



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportSubscriptionScheduleTypeChild(Model):
    """ReportSubscriptionScheduleTypeChild.

    :param report_subscription_schedule_type_id: The identifier of the
     subscription schedule type
    :type report_subscription_schedule_type_id: int
    :param report_subscription_schedule_type_name: The name of the
     subscription schedule type
    :type report_subscription_schedule_type_name: str
    """

    _attribute_map = {
        'report_subscription_schedule_type_id': {'key': 'reportSubscriptionScheduleTypeId', 'type': 'int'},
        'report_subscription_schedule_type_name': {'key': 'reportSubscriptionScheduleTypeName', 'type': 'str'},
    }

    def __init__(self, report_subscription_schedule_type_id=None, report_subscription_schedule_type_name=None):
        super(ReportSubscriptionScheduleTypeChild, self).__init__()
        self.report_subscription_schedule_type_id = report_subscription_schedule_type_id
        self.report_subscription_schedule_type_name = report_subscription_schedule_type_name



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillHeaderUpdateControlCodeChild(Model):
    """Control Code.

    :param control_code:  <span class='property-internal'>Must be between 0
     and 255 characters</span> <span class='property-internal'>Required
     (defined)</span>
    :type control_code: str
    :param update: Indicates whether or not the header value is being updated
     <span class='property-internal'>Required</span>
    :type update: bool
    """

    _validation = {
        'control_code': {'max_length': 255, 'min_length': 0},
        'update': {'required': True},
    }

    _attribute_map = {
        'control_code': {'key': 'controlCode', 'type': 'str'},
        'update': {'key': 'update', 'type': 'bool'},
    }

    def __init__(self, update, control_code=None):
        super(BillHeaderUpdateControlCodeChild, self).__init__()
        self.control_code = control_code
        self.update = update



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportBatchChild(Model):
    """ReportBatchChild.

    :param report_batch_id: The report batch ID
    :type report_batch_id: int
    :param report_batch_code: The report batch code
    :type report_batch_code: str
    :param report_batch_name: The report batch name
    :type report_batch_name: str
    """

    _attribute_map = {
        'report_batch_id': {'key': 'reportBatchId', 'type': 'int'},
        'report_batch_code': {'key': 'reportBatchCode', 'type': 'str'},
        'report_batch_name': {'key': 'reportBatchName', 'type': 'str'},
    }

    def __init__(self, report_batch_id=None, report_batch_code=None, report_batch_name=None):
        super(ReportBatchChild, self).__init__()
        self.report_batch_id = report_batch_id
        self.report_batch_code = report_batch_code
        self.report_batch_name = report_batch_name



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SystemSettingsRequest(Model):
    """SystemSettingsRequest.

    :param organization_name: The organization name <span
     class='property-internal'>Required (defined)</span>
    :type organization_name: str
    :param display_organization_name_in_header: Indicates whether or not
     organization name should be displayed in the application header <span
     class='property-internal'>Required</span>
    :type display_organization_name_in_header: bool
    :param organization_logo: The organization logo
     May be a base64-encoded PNG, JPG, or SVG image or a URI for an image
     hosted online
     A null value will clear the saved image <span
     class='property-internal'>Required (defined)</span>
    :type organization_logo: str
    :param automatic_logout_minutes: Number of minutes after which users will
     be automatically logged out <span class='property-internal'>Must be
     between 10 and 780</span> <span class='property-internal'>Required
     (defined)</span>
    :type automatic_logout_minutes: int
    :param default_country: Default country for new users <span
     class='property-internal'>Required (defined)</span>
    :type default_country: str
    :param default_meter_time_zone_id: ID of the default time zone for new
     meters <span class='property-internal'>Required</span>
    :type default_meter_time_zone_id: int
    :param default_date_format: Default date format for new users <span
     class='property-internal'>One of MM/dd/yyyy, dd/MM/yyyy </span> <span
     class='property-internal'>Required (defined)</span>
    :type default_date_format: str
    :param default_topmost_cost_center_id: Default topmost cost center ID for
     new users <span class='property-internal'>Required (defined)</span>
    :type default_topmost_cost_center_id: int
    :param default_topmost_place_id: Default topmost place ID for new users
     <span class='property-internal'>Required (defined)</span>
    :type default_topmost_place_id: int
    :param default_user_role_id: Default user role ID for new users <span
     class='property-internal'>Required (defined)</span>
    :type default_user_role_id: int
    """

    _validation = {
        'display_organization_name_in_header': {'required': True},
        'organization_logo': {'min_length': 5},
        'automatic_logout_minutes': {'maximum': 780, 'minimum': 10},
        'default_meter_time_zone_id': {'required': True},
    }

    _attribute_map = {
        'organization_name': {'key': 'organizationName', 'type': 'str'},
        'display_organization_name_in_header': {'key': 'displayOrganizationNameInHeader', 'type': 'bool'},
        'organization_logo': {'key': 'organizationLogo', 'type': 'str'},
        'automatic_logout_minutes': {'key': 'automaticLogoutMinutes', 'type': 'int'},
        'default_country': {'key': 'defaultCountry', 'type': 'str'},
        'default_meter_time_zone_id': {'key': 'defaultMeterTimeZoneId', 'type': 'int'},
        'default_date_format': {'key': 'defaultDateFormat', 'type': 'str'},
        'default_topmost_cost_center_id': {'key': 'defaultTopmostCostCenterId', 'type': 'int'},
        'default_topmost_place_id': {'key': 'defaultTopmostPlaceId', 'type': 'int'},
        'default_user_role_id': {'key': 'defaultUserRoleId', 'type': 'int'},
    }

    def __init__(self, display_organization_name_in_header, default_meter_time_zone_id, organization_name=None, organization_logo=None, automatic_logout_minutes=None, default_country=None, default_date_format=None, default_topmost_cost_center_id=None, default_topmost_place_id=None, default_user_role_id=None):
        super(SystemSettingsRequest, self).__init__()
        self.organization_name = organization_name
        self.display_organization_name_in_header = display_organization_name_in_header
        self.organization_logo = organization_logo
        self.automatic_logout_minutes = automatic_logout_minutes
        self.default_country = default_country
        self.default_meter_time_zone_id = default_meter_time_zone_id
        self.default_date_format = default_date_format
        self.default_topmost_cost_center_id = default_topmost_cost_center_id
        self.default_topmost_place_id = default_topmost_place_id
        self.default_user_role_id = default_user_role_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarSettingsRequest(Model):
    """EnergyStarSettingsRequest.

    :param notification_recipients: List of e-mail notification recipients
     <span class='property-internal'>Required</span> <span
     class='property-internal'>Cannot be Empty</span>
    :type notification_recipients: list[str]
    :param earliest_submission_period: The earliest period to submit <span
     class='property-internal'>Required</span>
    :type earliest_submission_period: int
    """

    _validation = {
        'notification_recipients': {'required': True},
        'earliest_submission_period': {'required': True},
    }

    _attribute_map = {
        'notification_recipients': {'key': 'notificationRecipients', 'type': '[str]'},
        'earliest_submission_period': {'key': 'earliestSubmissionPeriod', 'type': 'int'},
    }

    def __init__(self, notification_recipients, earliest_submission_period):
        super(EnergyStarSettingsRequest, self).__init__()
        self.notification_recipients = notification_recipients
        self.earliest_submission_period = earliest_submission_period



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccrualProcessorRequest(Model):
    """AccrualProcessorRequest.

    :param batch_code: The batch to create for accrual bills <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type batch_code: str
    :param auc_safety_net: Use a safety net for accrued cost calculation?
     - if we have usage and we are using an average unit cost safety net and
     the most recent unit cost does not vary more than the specified percentage
     from the historical average unit cost,
     accrued cost = accrued use * most recent unit cost
     - if we have usage and we are not using an average unit cost safety net or
     the most recent unit cost does vary more than the specified percentage
     from the historical average unit cost,
     accrued cost = accrued use * average historical unit cost
     - if we don't have usage,
     accrued cost = historical average cost per day * number of days in accrual
     period <span class='property-internal'>Required</span>
    :type auc_safety_net: bool
    :param auc_percent_variance_allowed: Percent of cost variance allowed when
     using average unit cost safety net <span
     class='property-internal'>Required when AucSafetyNet is set to True</span>
    :type auc_percent_variance_allowed: float
    :param accrual_period_end_date: End date for accrual bills generated <span
     class='property-internal'>Required</span>
    :type accrual_period_end_date: datetime
    :param accrual_period_minimum_start_date: Earliest bill end date to begin
     accruing from (end dates become begin dates for accrued bills) <span
     class='property-internal'>Required</span>
    :type accrual_period_minimum_start_date: datetime
    :param billing_period_calculation_method: Billing period calculation
     method.  Valid values are "bill midpoint" and "manual". <span
     class='property-internal'>One of bill midpoint, manual </span> <span
     class='property-internal'>Required</span>
    :type billing_period_calculation_method: str
    :param manual_billing_period: Fixed billing period for accrual bills
     generated when billing period calculation method is manual. <span
     class='property-internal'>Required when BillingPeriodCalculationMethod is
     set to manual</span> <span class='property-internal'>Must be between
     190001 and 209912</span>
    :type manual_billing_period: int
    :param account_period_calculation_method: Account period calculation
     method.  Valid values are "blank", "billing period" and "manual". <span
     class='property-internal'>One of blank, billing period, manual </span>
     <span class='property-internal'>Required</span>
    :type account_period_calculation_method: str
    :param manual_account_period: Fixed account period for accrual bills
     generated when account period calculation method is manual. <span
     class='property-internal'>Required when AccountPeriodCalculationMethod is
     set to manual</span> <span class='property-internal'>Must be between
     190001 and 209913</span>
    :type manual_account_period: int
    :param test_mode: Generate accrual bills in test mode? Test mode bills are
     created as voided bills. <span class='property-internal'>Required</span>
    :type test_mode: bool
    """

    _validation = {
        'batch_code': {'required': True, 'max_length': 255, 'min_length': 0},
        'auc_safety_net': {'required': True},
        'accrual_period_end_date': {'required': True},
        'accrual_period_minimum_start_date': {'required': True},
        'billing_period_calculation_method': {'required': True},
        'manual_billing_period': {'maximum': 209912, 'minimum': 190001},
        'account_period_calculation_method': {'required': True},
        'manual_account_period': {'maximum': 209913, 'minimum': 190001},
        'test_mode': {'required': True},
    }

    _attribute_map = {
        'batch_code': {'key': 'batchCode', 'type': 'str'},
        'auc_safety_net': {'key': 'aucSafetyNet', 'type': 'bool'},
        'auc_percent_variance_allowed': {'key': 'aucPercentVarianceAllowed', 'type': 'float'},
        'accrual_period_end_date': {'key': 'accrualPeriodEndDate', 'type': 'iso-8601'},
        'accrual_period_minimum_start_date': {'key': 'accrualPeriodMinimumStartDate', 'type': 'iso-8601'},
        'billing_period_calculation_method': {'key': 'billingPeriodCalculationMethod', 'type': 'str'},
        'manual_billing_period': {'key': 'manualBillingPeriod', 'type': 'int'},
        'account_period_calculation_method': {'key': 'accountPeriodCalculationMethod', 'type': 'str'},
        'manual_account_period': {'key': 'manualAccountPeriod', 'type': 'int'},
        'test_mode': {'key': 'testMode', 'type': 'bool'},
    }

    def __init__(self, batch_code, auc_safety_net, accrual_period_end_date, accrual_period_minimum_start_date, billing_period_calculation_method, account_period_calculation_method, test_mode, auc_percent_variance_allowed=None, manual_billing_period=None, manual_account_period=None):
        super(AccrualProcessorRequest, self).__init__()
        self.batch_code = batch_code
        self.auc_safety_net = auc_safety_net
        self.auc_percent_variance_allowed = auc_percent_variance_allowed
        self.accrual_period_end_date = accrual_period_end_date
        self.accrual_period_minimum_start_date = accrual_period_minimum_start_date
        self.billing_period_calculation_method = billing_period_calculation_method
        self.manual_billing_period = manual_billing_period
        self.account_period_calculation_method = account_period_calculation_method
        self.manual_account_period = manual_account_period
        self.test_mode = test_mode



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SavingsMeterBillResponse(Model):
    """SavingsMeterBillResponse.

    :param bill_mtr_cap_id: Unique ID for this savings record (Bill Meter CAP)
    :type bill_mtr_cap_id: int
    :param bill_id: Unique ID of the bill processed for this savings record
    :type bill_id: int
    :param period_name: Calendar Period Name (e.g. Jan)
    :type period_name: str
    :param calendar_period: Calendar Period Number (e.g. 4)
    :type calendar_period: int
    :param calendar_year: Calendar Year (e.g. 2019)
    :type calendar_year: int
    :param fiscal_period: Fiscal Period Number
    :type fiscal_period: int
    :param fiscal_year: Fiscal Year
    :type fiscal_year: int
    :param baseline_cost: Baseline Cost
    :type baseline_cost: float
    :param baseline_native_use: Baseline Native Use
    :type baseline_native_use: float
    :param baseline_weather_native_use: Baseline Weather Native Use
    :type baseline_weather_native_use: float
    :param baseline_nonweather_native_use: Baseline Nonweather Native Use
    :type baseline_nonweather_native_use: float
    :param batcc_cost: Baseline Adjusted to Curent Conditions (BATCC) Cost
    :type batcc_cost: float
    :param batcc_native_use: Baseline Adjusted to Curent Conditions (BATCC)
     Native Use
    :type batcc_native_use: float
    :param batcc_weather_native_use: Baseline Adjusted to Curent Conditions
     (BATCC) Weather Native Use
    :type batcc_weather_native_use: float
    :param batcc_nonweather_native_use: Baseline Adjusted to Curent Conditions
     (BATCC) Nonweather Native Use
    :type batcc_nonweather_native_use: float
    :param actual_cost: Actual Cost
    :type actual_cost: float
    :param actual_native_use: Actual Native Use
    :type actual_native_use: float
    :param savings_cost: Savings Cost
    :type savings_cost: float
    :param savings_native_use: Savings Native Use
    :type savings_native_use: float
    :param savings_cost_percent: Savings Cost Percent
    :type savings_cost_percent: float
    :param savings_native_use_percent: Savings Native Use Percent
    :type savings_native_use_percent: float
    :param hdd: Heating Degree Days
    :type hdd: int
    :param cdd: Cooling Degree Days
    :type cdd: int
    :param hdd_adjusted: Heating Degree Days Adjusted
    :type hdd_adjusted: bool
    :param cdd_adjusted: Cooling Degree Days Adjusted
    :type cdd_adjusted: bool
    :param heating_use_per_degree_day: Heating Use Per Degree Day
    :type heating_use_per_degree_day: float
    :param heat_r2: Heating R2
    :type heat_r2: float
    :param cooling_use_per_degree_day: Cooling Use Per Degree Day
    :type cooling_use_per_degree_day: float
    :param cool_r2: Cooling R2
    :type cool_r2: float
    :param cap_status: Cost Avoidance Status
    :type cap_status: str
    :param locked: Indicates whether or not the bill's cost avoidance data is
     locked
    :type locked: bool
    :param bill_mtr_notes:
    :type bill_mtr_notes: list[str]
    :param native_use_unit:
    :type native_use_unit: ~energycap.sdk.models.UnitChild
    :param review:
    :type review: ~energycap.sdk.models.Reviewed
    :param account:
    :type account: ~energycap.sdk.models.AccountChild
    :param meter:
    :type meter: ~energycap.sdk.models.MeterChild
    :param place:
    :type place: ~energycap.sdk.models.PlaceChild
    :param cost_unit:
    :type cost_unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'bill_mtr_cap_id': {'key': 'billMtrCapId', 'type': 'int'},
        'bill_id': {'key': 'billId', 'type': 'int'},
        'period_name': {'key': 'periodName', 'type': 'str'},
        'calendar_period': {'key': 'calendarPeriod', 'type': 'int'},
        'calendar_year': {'key': 'calendarYear', 'type': 'int'},
        'fiscal_period': {'key': 'fiscalPeriod', 'type': 'int'},
        'fiscal_year': {'key': 'fiscalYear', 'type': 'int'},
        'baseline_cost': {'key': 'baselineCost', 'type': 'float'},
        'baseline_native_use': {'key': 'baselineNativeUse', 'type': 'float'},
        'baseline_weather_native_use': {'key': 'baselineWeatherNativeUse', 'type': 'float'},
        'baseline_nonweather_native_use': {'key': 'baselineNonweatherNativeUse', 'type': 'float'},
        'batcc_cost': {'key': 'batccCost', 'type': 'float'},
        'batcc_native_use': {'key': 'batccNativeUse', 'type': 'float'},
        'batcc_weather_native_use': {'key': 'batccWeatherNativeUse', 'type': 'float'},
        'batcc_nonweather_native_use': {'key': 'batccNonweatherNativeUse', 'type': 'float'},
        'actual_cost': {'key': 'actualCost', 'type': 'float'},
        'actual_native_use': {'key': 'actualNativeUse', 'type': 'float'},
        'savings_cost': {'key': 'savingsCost', 'type': 'float'},
        'savings_native_use': {'key': 'savingsNativeUse', 'type': 'float'},
        'savings_cost_percent': {'key': 'savingsCostPercent', 'type': 'float'},
        'savings_native_use_percent': {'key': 'savingsNativeUsePercent', 'type': 'float'},
        'hdd': {'key': 'hdd', 'type': 'int'},
        'cdd': {'key': 'cdd', 'type': 'int'},
        'hdd_adjusted': {'key': 'hddAdjusted', 'type': 'bool'},
        'cdd_adjusted': {'key': 'cddAdjusted', 'type': 'bool'},
        'heating_use_per_degree_day': {'key': 'heatingUsePerDegreeDay', 'type': 'float'},
        'heat_r2': {'key': 'heatR2', 'type': 'float'},
        'cooling_use_per_degree_day': {'key': 'coolingUsePerDegreeDay', 'type': 'float'},
        'cool_r2': {'key': 'coolR2', 'type': 'float'},
        'cap_status': {'key': 'capStatus', 'type': 'str'},
        'locked': {'key': 'locked', 'type': 'bool'},
        'bill_mtr_notes': {'key': 'billMtrNotes', 'type': '[str]'},
        'native_use_unit': {'key': 'nativeUseUnit', 'type': 'UnitChild'},
        'review': {'key': 'review', 'type': 'Reviewed'},
        'account': {'key': 'account', 'type': 'AccountChild'},
        'meter': {'key': 'meter', 'type': 'MeterChild'},
        'place': {'key': 'place', 'type': 'PlaceChild'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
    }

    def __init__(self, bill_mtr_cap_id=None, bill_id=None, period_name=None, calendar_period=None, calendar_year=None, fiscal_period=None, fiscal_year=None, baseline_cost=None, baseline_native_use=None, baseline_weather_native_use=None, baseline_nonweather_native_use=None, batcc_cost=None, batcc_native_use=None, batcc_weather_native_use=None, batcc_nonweather_native_use=None, actual_cost=None, actual_native_use=None, savings_cost=None, savings_native_use=None, savings_cost_percent=None, savings_native_use_percent=None, hdd=None, cdd=None, hdd_adjusted=None, cdd_adjusted=None, heating_use_per_degree_day=None, heat_r2=None, cooling_use_per_degree_day=None, cool_r2=None, cap_status=None, locked=None, bill_mtr_notes=None, native_use_unit=None, review=None, account=None, meter=None, place=None, cost_unit=None):
        super(SavingsMeterBillResponse, self).__init__()
        self.bill_mtr_cap_id = bill_mtr_cap_id
        self.bill_id = bill_id
        self.period_name = period_name
        self.calendar_period = calendar_period
        self.calendar_year = calendar_year
        self.fiscal_period = fiscal_period
        self.fiscal_year = fiscal_year
        self.baseline_cost = baseline_cost
        self.baseline_native_use = baseline_native_use
        self.baseline_weather_native_use = baseline_weather_native_use
        self.baseline_nonweather_native_use = baseline_nonweather_native_use
        self.batcc_cost = batcc_cost
        self.batcc_native_use = batcc_native_use
        self.batcc_weather_native_use = batcc_weather_native_use
        self.batcc_nonweather_native_use = batcc_nonweather_native_use
        self.actual_cost = actual_cost
        self.actual_native_use = actual_native_use
        self.savings_cost = savings_cost
        self.savings_native_use = savings_native_use
        self.savings_cost_percent = savings_cost_percent
        self.savings_native_use_percent = savings_native_use_percent
        self.hdd = hdd
        self.cdd = cdd
        self.hdd_adjusted = hdd_adjusted
        self.cdd_adjusted = cdd_adjusted
        self.heating_use_per_degree_day = heating_use_per_degree_day
        self.heat_r2 = heat_r2
        self.cooling_use_per_degree_day = cooling_use_per_degree_day
        self.cool_r2 = cool_r2
        self.cap_status = cap_status
        self.locked = locked
        self.bill_mtr_notes = bill_mtr_notes
        self.native_use_unit = native_use_unit
        self.review = review
        self.account = account
        self.meter = meter
        self.place = place
        self.cost_unit = cost_unit



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterEdit(Model):
    """MeterEdit.

    :param meter_code: The meter code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type meter_code: str
    :param meter_info: The meter info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 50 characters</span>
    :type meter_info: str
    :param place_id: The identifier for the place the meter is assigned to
     <span class='property-internal'>Topmost (Place)</span> <span
     class='property-internal'>Required</span>
    :type place_id: int
    :param commodity_id: The commodity identifier that the meter is assigned
     to.
     If different from original commodity id, then a commodity change will be
     attempted. <span class='property-internal'>Required</span>
    :type commodity_id: int
    :param address:
    :type address: ~energycap.sdk.models.AddressChild
    :param bill_entry_note: The bill entry note <span
     class='property-internal'>Must be between 0 and 64 characters</span> <span
     class='property-internal'>Required (defined)</span>
    :type bill_entry_note: str
    :param include_in_energy_star: DEPRECATED
     To be included in ENERGY STAR a meter needs to be linked to a meter in
     Portfolio Manager
     This can be done with the PUT place/{placeId}/energyStar/link or the
     ENERGY STAR: Mappings Setup Sheet <span class='property-internal'>Required
     (defined)</span>
    :type include_in_energy_star: bool
    :param primary_use_id: The identifier for the meter's primary use <span
     class='property-internal'>Required (defined)</span>
    :type primary_use_id: int
    :param meter_time_zone_id: The identifier for the meter's time zone. <span
     class='property-internal'>Required</span>
    :type meter_time_zone_id: int
    :param active: Is this meter active? <span
     class='property-internal'>Required</span>
    :type active: bool
    :param properties: An array of meter properties <span
     class='property-internal'>Required (defined)</span>
    :type properties: dict[str, str]
    :param use_unit_id: The use unit ID is the reporting unit for use for this
     meter.
     If it is set to -1 or null, then no change will be made.
     Please see DemandUnitId summary as well <span
     class='property-internal'>Required (defined)</span>
    :type use_unit_id: int
    :param demand_unit_id: The demand unit ID is the reporting unit for demand
     for this meter.
     If this property does not exist, then no change will be made.
     If this property exists and its value is -1, then no change will be made.
     If this property exists and its value is null AND useUnitId is null then
     no change will be made.
     If this property is sent in as null AND useUnitId is NOT null, then the
     meter's demand unit ID will be set to null.
     Please see UseUnitID summary as well <span
     class='property-internal'>Required (defined)</span>
    :type demand_unit_id: int
    :param meter_description: A description of the meter <span
     class='property-internal'>Must be between 0 and 4000 characters</span>
     <span class='property-internal'>Required (defined)</span>. Default value:
     "Æ" .
    :type meter_description: str
    """

    _validation = {
        'meter_code': {'required': True, 'max_length': 32, 'min_length': 0},
        'meter_info': {'required': True, 'max_length': 50, 'min_length': 0},
        'place_id': {'required': True},
        'commodity_id': {'required': True},
        'bill_entry_note': {'max_length': 64, 'min_length': 0},
        'meter_time_zone_id': {'required': True},
        'active': {'required': True},
        'meter_description': {'max_length': 4000, 'min_length': 0},
    }

    _attribute_map = {
        'meter_code': {'key': 'meterCode', 'type': 'str'},
        'meter_info': {'key': 'meterInfo', 'type': 'str'},
        'place_id': {'key': 'placeId', 'type': 'int'},
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'address': {'key': 'address', 'type': 'AddressChild'},
        'bill_entry_note': {'key': 'billEntryNote', 'type': 'str'},
        'include_in_energy_star': {'key': 'includeInEnergyStar', 'type': 'bool'},
        'primary_use_id': {'key': 'primaryUseId', 'type': 'int'},
        'meter_time_zone_id': {'key': 'meterTimeZoneId', 'type': 'int'},
        'active': {'key': 'active', 'type': 'bool'},
        'properties': {'key': 'properties', 'type': '{str}'},
        'use_unit_id': {'key': 'useUnitId', 'type': 'int'},
        'demand_unit_id': {'key': 'demandUnitId', 'type': 'int'},
        'meter_description': {'key': 'meterDescription', 'type': 'str'},
    }

    def __init__(self, meter_code, meter_info, place_id, commodity_id, meter_time_zone_id, active, address=None, bill_entry_note=None, include_in_energy_star=None, primary_use_id=None, properties=None, use_unit_id=None, demand_unit_id=None, meter_description="Æ"):
        super(MeterEdit, self).__init__()
        self.meter_code = meter_code
        self.meter_info = meter_info
        self.place_id = place_id
        self.commodity_id = commodity_id
        self.address = address
        self.bill_entry_note = bill_entry_note
        self.include_in_energy_star = include_in_energy_star
        self.primary_use_id = primary_use_id
        self.meter_time_zone_id = meter_time_zone_id
        self.active = active
        self.properties = properties
        self.use_unit_id = use_unit_id
        self.demand_unit_id = demand_unit_id
        self.meter_description = meter_description



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillActionCustom(Model):
    """BillActionCustom.

    :param bill_ids: The list of bill ids on which to perform the custom
     action <span class='property-internal'>Cannot be Empty</span> <span
     class='property-internal'>Required (defined)</span>
    :type bill_ids: list[int]
    :param webhook_id: The webhook identifier that represents the custom bill
     action <span class='property-internal'>Required</span>
    :type webhook_id: int
    """

    _validation = {
        'webhook_id': {'required': True},
    }

    _attribute_map = {
        'bill_ids': {'key': 'billIds', 'type': '[int]'},
        'webhook_id': {'key': 'webhookId', 'type': 'int'},
    }

    def __init__(self, webhook_id, bill_ids=None):
        super(BillActionCustom, self).__init__()
        self.bill_ids = bill_ids
        self.webhook_id = webhook_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Setup(Model):
    """Setup.

    :param type: Type of importer. Possible values include: 'UNKNOWNTYPE',
     'CREATE_AccountsAndMeters', 'CREATE_BuildingsAndOrganizations',
     'CREATE_CostAvoidanceOtherSavings',
     'CREATE_CostAvoidanceSpecialAdjustments', 'CREATE_CostCenters',
     'CREATE_Customers', 'CREATE_ChargebackDistributionsVersions',
     'CREATE_RateSchedules', 'CREATE_Vendors', 'CREATE_Channels',
     'UPDATE_CostCenters', 'UPDATE_BuildingsAndOrganizations',
     'UPDATE_AccountingCalendar', 'UPDATE_Accounts',
     'UPDATE_CustomFieldsAccount', 'UPDATE_CostAvoidanceOtherSavings',
     'UPDATE_CostAvoidanceSpecialAdjustments', 'UPDATE_Customers',
     'CREATE_GLCodesAndSubcodes', 'UPDATE_GLCodesAndSubcodes', 'UPDATE_Meters',
     'UPDATE_CustomFieldsMeter', 'UPDATE_CustomFieldsPlace', 'UPDATE_Users',
     'UPDATE_Vendors', 'UPDATE_CustomFieldsVendor', 'CREATE_Users',
     'UPDATE_Channels', 'UPDATE_BillCalculations', 'CREATE_BillCalculations',
     'UPDATE_BillSplits', 'CREATE_BillSplits', 'UPDATE_MeterGroups',
     'UPDATE_BuildingGroups', 'CONVERT_BillSplits', 'CONVERT_BillCalculations',
     'CREATE_Readings', 'UPDATE_Readings', 'CREATE_MonthlyReadings',
     'CREATE_PlaceBenchmarks', 'UPDATE_PlaceBenchmarks', 'CREATE_UserGroups',
     'UPDATE_UserGroups', 'UPDATE_UserGroupMembers',
     'UPDATE_PlaceEnergyStarLink', 'CREATE_BudgetWorksheet'
    :type type: str or ~energycap.sdk.models.enum
    :param sheet_type: Type of sheet that was imported
    :type sheet_type: str
    :param action: Action that was performed - create, update, convert
    :type action: str
    :param success: Count of rows that succeeded
    :type success: int
    :param failure: Count of rows that failed
    :type failure: int
    :param skip: Count of rows that were skipped
    :type skip: int
    :param kickout: A stream that represents the kickout file
    :type kickout: str
    :param start: Time at which the import started
    :type start: datetime
    :param finish: Time at which the import finished
    :type finish: datetime
    :param task_id: Unique identifier for this import
    :type task_id: int
    """

    _attribute_map = {
        'type': {'key': 'type', 'type': 'str'},
        'sheet_type': {'key': 'sheetType', 'type': 'str'},
        'action': {'key': 'action', 'type': 'str'},
        'success': {'key': 'success', 'type': 'int'},
        'failure': {'key': 'failure', 'type': 'int'},
        'skip': {'key': 'skip', 'type': 'int'},
        'kickout': {'key': 'kickout', 'type': 'str'},
        'start': {'key': 'start', 'type': 'iso-8601'},
        'finish': {'key': 'finish', 'type': 'iso-8601'},
        'task_id': {'key': 'taskId', 'type': 'int'},
    }

    def __init__(self, type=None, sheet_type=None, action=None, success=None, failure=None, skip=None, kickout=None, start=None, finish=None, task_id=None):
        super(Setup, self).__init__()
        self.type = type
        self.sheet_type = sheet_type
        self.action = action
        self.success = success
        self.failure = failure
        self.skip = skip
        self.kickout = kickout
        self.start = start
        self.finish = finish
        self.task_id = task_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AuditSettings(Model):
    """AuditSettings.

    :param bill_contains_line_item_descriptions:
    :type bill_contains_line_item_descriptions:
     ~energycap.sdk.models.BillContainsLineItemDescriptionsSetting
    :param bill_contains_line_item_types:
    :type bill_contains_line_item_types:
     ~energycap.sdk.models.BillContainsLineItemTypesSetting
    :param total_bill_cost_does_not_match_line_item_types:
    :type total_bill_cost_does_not_match_line_item_types:
     ~energycap.sdk.models.TotalBillCostDoesNotMatchLineItemTypesSetting
    :param billing_period_outside_start_end_dates:
    :type billing_period_outside_start_end_dates:
     ~energycap.sdk.models.AuditSetting
    :param bill_overlaps_with_other_account_bill:
    :type bill_overlaps_with_other_account_bill:
     ~energycap.sdk.models.AuditSetting
    :param gap_between_bill_and_previous_bill_on_account:
    :type gap_between_bill_and_previous_bill_on_account:
     ~energycap.sdk.models.AuditSetting
    :param bill_ends_in_future:
    :type bill_ends_in_future: ~energycap.sdk.models.AuditSetting
    :param account_has_multiple_bills_in_billing_period:
    :type account_has_multiple_bills_in_billing_period:
     ~energycap.sdk.models.AuditSetting
    :param statement_date_before_end_date:
    :type statement_date_before_end_date: ~energycap.sdk.models.AuditSetting
    :param due_date_before_end_date:
    :type due_date_before_end_date: ~energycap.sdk.models.AuditSetting
    :param bill_significantly_shorter_or_longer_than_previous:
    :type bill_significantly_shorter_or_longer_than_previous:
     ~energycap.sdk.models.BillSignificantlyShorterOrLongerThanPreviousSetting
    :param too_many_consecutive_estimated_bills:
    :type too_many_consecutive_estimated_bills:
     ~energycap.sdk.models.TooManyConsecutiveEstimatedBillsSetting
    :param due_date_too_long_after_bill_end:
    :type due_date_too_long_after_bill_end:
     ~energycap.sdk.models.DueDateTooLongAfterBillEndSetting
    :param statement_date_too_long_after_bill_end:
    :type statement_date_too_long_after_bill_end:
     ~energycap.sdk.models.StatementDateTooLongAfterBillEndSetting
    :param invoice_number_is_repeated_on_account:
    :type invoice_number_is_repeated_on_account:
     ~energycap.sdk.models.AuditSetting
    :param likely_duplicate_bill_on_account:
    :type likely_duplicate_bill_on_account: ~energycap.sdk.models.AuditSetting
    :param total_meter_cost_is_percentage_higher_than_past_year:
    :type total_meter_cost_is_percentage_higher_than_past_year:
     ~energycap.sdk.models.AuditSetting
    :param total_meter_use_is_percentage_higher_than_past_year:
    :type total_meter_use_is_percentage_higher_than_past_year:
     ~energycap.sdk.models.AuditSetting
    :param serial_number_does_not_match_import_file:
    :type serial_number_does_not_match_import_file:
     ~energycap.sdk.models.AuditSetting
    :param rate_code_does_not_match_import_file:
    :type rate_code_does_not_match_import_file:
     ~energycap.sdk.models.AuditSetting
    :param import_file_start_date_adjusted_to_prevent_gaps:
    :type import_file_start_date_adjusted_to_prevent_gaps:
     ~energycap.sdk.models.AuditSetting
    :param account_alert_exists_on_account_in_import_file:
    :type account_alert_exists_on_account_in_import_file:
     ~energycap.sdk.models.AuditSetting
    """

    _validation = {
        'bill_contains_line_item_descriptions': {'required': True},
        'bill_contains_line_item_types': {'required': True},
        'total_bill_cost_does_not_match_line_item_types': {'required': True},
        'billing_period_outside_start_end_dates': {'required': True},
        'bill_overlaps_with_other_account_bill': {'required': True},
        'gap_between_bill_and_previous_bill_on_account': {'required': True},
        'bill_ends_in_future': {'required': True},
        'account_has_multiple_bills_in_billing_period': {'required': True},
        'statement_date_before_end_date': {'required': True},
        'due_date_before_end_date': {'required': True},
        'bill_significantly_shorter_or_longer_than_previous': {'required': True},
        'too_many_consecutive_estimated_bills': {'required': True},
        'due_date_too_long_after_bill_end': {'required': True},
        'statement_date_too_long_after_bill_end': {'required': True},
        'invoice_number_is_repeated_on_account': {'required': True},
        'likely_duplicate_bill_on_account': {'required': True},
        'total_meter_cost_is_percentage_higher_than_past_year': {'required': True},
        'total_meter_use_is_percentage_higher_than_past_year': {'required': True},
        'serial_number_does_not_match_import_file': {'required': True},
        'rate_code_does_not_match_import_file': {'required': True},
        'import_file_start_date_adjusted_to_prevent_gaps': {'required': True},
        'account_alert_exists_on_account_in_import_file': {'required': True},
    }

    _attribute_map = {
        'bill_contains_line_item_descriptions': {'key': 'billContainsLineItemDescriptions', 'type': 'BillContainsLineItemDescriptionsSetting'},
        'bill_contains_line_item_types': {'key': 'billContainsLineItemTypes', 'type': 'BillContainsLineItemTypesSetting'},
        'total_bill_cost_does_not_match_line_item_types': {'key': 'totalBillCostDoesNotMatchLineItemTypes', 'type': 'TotalBillCostDoesNotMatchLineItemTypesSetting'},
        'billing_period_outside_start_end_dates': {'key': 'billingPeriodOutsideStartEndDates', 'type': 'AuditSetting'},
        'bill_overlaps_with_other_account_bill': {'key': 'billOverlapsWithOtherAccountBill', 'type': 'AuditSetting'},
        'gap_between_bill_and_previous_bill_on_account': {'key': 'gapBetweenBillAndPreviousBillOnAccount', 'type': 'AuditSetting'},
        'bill_ends_in_future': {'key': 'billEndsInFuture', 'type': 'AuditSetting'},
        'account_has_multiple_bills_in_billing_period': {'key': 'accountHasMultipleBillsInBillingPeriod', 'type': 'AuditSetting'},
        'statement_date_before_end_date': {'key': 'statementDateBeforeEndDate', 'type': 'AuditSetting'},
        'due_date_before_end_date': {'key': 'dueDateBeforeEndDate', 'type': 'AuditSetting'},
        'bill_significantly_shorter_or_longer_than_previous': {'key': 'billSignificantlyShorterOrLongerThanPrevious', 'type': 'BillSignificantlyShorterOrLongerThanPreviousSetting'},
        'too_many_consecutive_estimated_bills': {'key': 'tooManyConsecutiveEstimatedBills', 'type': 'TooManyConsecutiveEstimatedBillsSetting'},
        'due_date_too_long_after_bill_end': {'key': 'dueDateTooLongAfterBillEnd', 'type': 'DueDateTooLongAfterBillEndSetting'},
        'statement_date_too_long_after_bill_end': {'key': 'statementDateTooLongAfterBillEnd', 'type': 'StatementDateTooLongAfterBillEndSetting'},
        'invoice_number_is_repeated_on_account': {'key': 'invoiceNumberIsRepeatedOnAccount', 'type': 'AuditSetting'},
        'likely_duplicate_bill_on_account': {'key': 'likelyDuplicateBillOnAccount', 'type': 'AuditSetting'},
        'total_meter_cost_is_percentage_higher_than_past_year': {'key': 'totalMeterCostIsPercentageHigherThanPastYear', 'type': 'AuditSetting'},
        'total_meter_use_is_percentage_higher_than_past_year': {'key': 'totalMeterUseIsPercentageHigherThanPastYear', 'type': 'AuditSetting'},
        'serial_number_does_not_match_import_file': {'key': 'serialNumberDoesNotMatchImportFile', 'type': 'AuditSetting'},
        'rate_code_does_not_match_import_file': {'key': 'rateCodeDoesNotMatchImportFile', 'type': 'AuditSetting'},
        'import_file_start_date_adjusted_to_prevent_gaps': {'key': 'importFileStartDateAdjustedToPreventGaps', 'type': 'AuditSetting'},
        'account_alert_exists_on_account_in_import_file': {'key': 'accountAlertExistsOnAccountInImportFile', 'type': 'AuditSetting'},
    }

    def __init__(self, bill_contains_line_item_descriptions, bill_contains_line_item_types, total_bill_cost_does_not_match_line_item_types, billing_period_outside_start_end_dates, bill_overlaps_with_other_account_bill, gap_between_bill_and_previous_bill_on_account, bill_ends_in_future, account_has_multiple_bills_in_billing_period, statement_date_before_end_date, due_date_before_end_date, bill_significantly_shorter_or_longer_than_previous, too_many_consecutive_estimated_bills, due_date_too_long_after_bill_end, statement_date_too_long_after_bill_end, invoice_number_is_repeated_on_account, likely_duplicate_bill_on_account, total_meter_cost_is_percentage_higher_than_past_year, total_meter_use_is_percentage_higher_than_past_year, serial_number_does_not_match_import_file, rate_code_does_not_match_import_file, import_file_start_date_adjusted_to_prevent_gaps, account_alert_exists_on_account_in_import_file):
        super(AuditSettings, self).__init__()
        self.bill_contains_line_item_descriptions = bill_contains_line_item_descriptions
        self.bill_contains_line_item_types = bill_contains_line_item_types
        self.total_bill_cost_does_not_match_line_item_types = total_bill_cost_does_not_match_line_item_types
        self.billing_period_outside_start_end_dates = billing_period_outside_start_end_dates
        self.bill_overlaps_with_other_account_bill = bill_overlaps_with_other_account_bill
        self.gap_between_bill_and_previous_bill_on_account = gap_between_bill_and_previous_bill_on_account
        self.bill_ends_in_future = bill_ends_in_future
        self.account_has_multiple_bills_in_billing_period = account_has_multiple_bills_in_billing_period
        self.statement_date_before_end_date = statement_date_before_end_date
        self.due_date_before_end_date = due_date_before_end_date
        self.bill_significantly_shorter_or_longer_than_previous = bill_significantly_shorter_or_longer_than_previous
        self.too_many_consecutive_estimated_bills = too_many_consecutive_estimated_bills
        self.due_date_too_long_after_bill_end = due_date_too_long_after_bill_end
        self.statement_date_too_long_after_bill_end = statement_date_too_long_after_bill_end
        self.invoice_number_is_repeated_on_account = invoice_number_is_repeated_on_account
        self.likely_duplicate_bill_on_account = likely_duplicate_bill_on_account
        self.total_meter_cost_is_percentage_higher_than_past_year = total_meter_cost_is_percentage_higher_than_past_year
        self.total_meter_use_is_percentage_higher_than_past_year = total_meter_use_is_percentage_higher_than_past_year
        self.serial_number_does_not_match_import_file = serial_number_does_not_match_import_file
        self.rate_code_does_not_match_import_file = rate_code_does_not_match_import_file
        self.import_file_start_date_adjusted_to_prevent_gaps = import_file_start_date_adjusted_to_prevent_gaps
        self.account_alert_exists_on_account_in_import_file = account_alert_exists_on_account_in_import_file



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RateCreate(Model):
    """RateCreate.

    :param name:  <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type name: str
    :param vendor_id:  <span class='property-internal'>Required</span>
    :type vendor_id: int
    :param commodity_id:  <span class='property-internal'>Required</span>
    :type commodity_id: int
    :param note:  <span class='property-internal'>Must be between 0 and 255
     characters</span>
    :type note: str
    """

    _validation = {
        'name': {'required': True, 'max_length': 255, 'min_length': 0},
        'vendor_id': {'required': True},
        'commodity_id': {'required': True},
        'note': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'vendor_id': {'key': 'vendorId', 'type': 'int'},
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'note': {'key': 'note', 'type': 'str'},
    }

    def __init__(self, name, vendor_id, commodity_id, note=None):
        super(RateCreate, self).__init__()
        self.name = name
        self.vendor_id = vendor_id
        self.commodity_id = commodity_id
        self.note = note



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountMeterEdit(Model):
    """AccountMeterEdit.

    :param begin_date: The beginning date and time for this account meter
     relationship <span class='property-internal'>Must be between 12/31/1899
     and 1/1/3000</span> <span class='property-internal'>Required
     (defined)</span>
    :type begin_date: datetime
    :param end_date: The ending date and time for this account meter
     relationship <span class='property-internal'>Must be between 12/31/1899
     and 1/1/3000</span> <span class='property-internal'>Required
     (defined)</span>
    :type end_date: datetime
    :param general_ledger_id: The identifier for the general ledger assigned
     to this account meter <span class='property-internal'>Required
     (defined)</span>
    :type general_ledger_id: int
    :param vendor_type_id: The identifier for the vendor type. Vendors may
     assume different types on different account meters <span
     class='property-internal'>Required (defined)</span>
    :type vendor_type_id: int
    """

    _attribute_map = {
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'general_ledger_id': {'key': 'generalLedgerId', 'type': 'int'},
        'vendor_type_id': {'key': 'vendorTypeId', 'type': 'int'},
    }

    def __init__(self, begin_date=None, end_date=None, general_ledger_id=None, vendor_type_id=None):
        super(AccountMeterEdit, self).__init__()
        self.begin_date = begin_date
        self.end_date = end_date
        self.general_ledger_id = general_ledger_id
        self.vendor_type_id = vendor_type_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SubtractResponse(Model):
    """SubtractResponse.

    :param subtract_meters: Meters in this list will have their use or cost
     subtracted during bill calculation
    :type subtract_meters: list[~energycap.sdk.models.MeterChild]
    :param subtract_meter_groups: Distinct meters from these meter groups will
     have their use or cost subtracted together during the bill calculation
    :type subtract_meter_groups: list[~energycap.sdk.models.MeterGroupChild]
    """

    _attribute_map = {
        'subtract_meters': {'key': 'subtractMeters', 'type': '[MeterChild]'},
        'subtract_meter_groups': {'key': 'subtractMeterGroups', 'type': '[MeterGroupChild]'},
    }

    def __init__(self, subtract_meters=None, subtract_meter_groups=None):
        super(SubtractResponse, self).__init__()
        self.subtract_meters = subtract_meters
        self.subtract_meter_groups = subtract_meter_groups



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterCreate(Model):
    """MeterCreate.

    :param meter_code: The meter code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type meter_code: str
    :param meter_info: The meter info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 50 characters</span>
    :type meter_info: str
    :param commodity_id: The identifier for the meter's commodity <span
     class='property-internal'>Required</span>
    :type commodity_id: int
    :param place_id: The identifier for the place the meter is assigned to
     <span class='property-internal'>Topmost (Place)</span> <span
     class='property-internal'>Required</span>
    :type place_id: int
    :param address:
    :type address: ~energycap.sdk.models.RequiredAddressChild
    :param bill_entry_note: The bill entry note <span
     class='property-internal'>Must be between 0 and 64 characters</span>
    :type bill_entry_note: str
    :param include_in_energy_star: DEPRECATED
     To be included in ENERGY STAR a meter needs to be linked to a meter in
     Portfolio Manager
     This can be done with the PUT place/{placeId}/energyStar/link or the
     ENERGY STAR: Mappings Setup Sheet
    :type include_in_energy_star: bool
    :param properties: An array of meter properties
    :type properties: dict[str, str]
    :param primary_use_id: The identifier for the meter's primary use
    :type primary_use_id: int
    :param meter_type_id: The identifier for the meter type. Allowed values
     include: 1 (standard meter) and 6 (chargeback meter) <span
     class='property-internal'>Required</span>
    :type meter_type_id: int
    :param meter_time_zone_id: The identifier for the meter's time zone. If
     one is not specified, the global default meter time zone will be used.
    :type meter_time_zone_id: int
    :param use_unit_id: The use unit ID is the reporting unit for use for this
     meter.
     It is used to determine initial bill format for this meter.
     If not provided defaults to the common unit for the meter commodity
    :type use_unit_id: int
    :param demand_unit_id: The demand unit ID is the reporting unit for demand
     for this meter.
     It is used to determine initial bill format for this meter.
    :type demand_unit_id: int
    :param meter_description: A description of the meter <span
     class='property-internal'>Must be between 0 and 4000 characters</span>
    :type meter_description: str
    """

    _validation = {
        'meter_code': {'required': True, 'max_length': 32, 'min_length': 0},
        'meter_info': {'required': True, 'max_length': 50, 'min_length': 0},
        'commodity_id': {'required': True},
        'place_id': {'required': True},
        'address': {'required': True},
        'bill_entry_note': {'max_length': 64, 'min_length': 0},
        'meter_type_id': {'required': True},
        'meter_description': {'max_length': 4000, 'min_length': 0},
    }

    _attribute_map = {
        'meter_code': {'key': 'meterCode', 'type': 'str'},
        'meter_info': {'key': 'meterInfo', 'type': 'str'},
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'place_id': {'key': 'placeId', 'type': 'int'},
        'address': {'key': 'address', 'type': 'RequiredAddressChild'},
        'bill_entry_note': {'key': 'billEntryNote', 'type': 'str'},
        'include_in_energy_star': {'key': 'includeInEnergyStar', 'type': 'bool'},
        'properties': {'key': 'properties', 'type': '{str}'},
        'primary_use_id': {'key': 'primaryUseId', 'type': 'int'},
        'meter_type_id': {'key': 'meterTypeId', 'type': 'int'},
        'meter_time_zone_id': {'key': 'meterTimeZoneId', 'type': 'int'},
        'use_unit_id': {'key': 'useUnitId', 'type': 'int'},
        'demand_unit_id': {'key': 'demandUnitId', 'type': 'int'},
        'meter_description': {'key': 'meterDescription', 'type': 'str'},
    }

    def __init__(self, meter_code, meter_info, commodity_id, place_id, address, meter_type_id, bill_entry_note=None, include_in_energy_star=None, properties=None, primary_use_id=None, meter_time_zone_id=None, use_unit_id=None, demand_unit_id=None, meter_description=None):
        super(MeterCreate, self).__init__()
        self.meter_code = meter_code
        self.meter_info = meter_info
        self.commodity_id = commodity_id
        self.place_id = place_id
        self.address = address
        self.bill_entry_note = bill_entry_note
        self.include_in_energy_star = include_in_energy_star
        self.properties = properties
        self.primary_use_id = primary_use_id
        self.meter_type_id = meter_type_id
        self.meter_time_zone_id = meter_time_zone_id
        self.use_unit_id = use_unit_id
        self.demand_unit_id = demand_unit_id
        self.meter_description = meter_description



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DistributionVersionResponse(Model):
    """DistributionVersionResponse.

    :param version_id: Identifier for the version
    :type version_id: int
    :param version_info: Name given to a version
    :type version_info: str
    :param chargeback_type: The chargeback type.  Either "Split" or
     "Calculation"
    :type chargeback_type: str
    :param begin_period: Begin period for the version
    :type begin_period: int
    :param end_period: End period for the version
     null value means continuing indefinitely
    :type end_period: int
    :param account:
    :type account: ~energycap.sdk.models.AccountChildWithType
    :param meter:
    :type meter: ~energycap.sdk.models.MeterChild
    :param workflow:
    :type workflow: ~energycap.sdk.models.ChargebackWorkflowStepChild
    :param has_bills: Do any bills exist that were created by this version?
     A version cannot be deleted if there are any existing bills that were
     created using this version
    :type has_bills: bool
    """

    _attribute_map = {
        'version_id': {'key': 'versionId', 'type': 'int'},
        'version_info': {'key': 'versionInfo', 'type': 'str'},
        'chargeback_type': {'key': 'chargebackType', 'type': 'str'},
        'begin_period': {'key': 'beginPeriod', 'type': 'int'},
        'end_period': {'key': 'endPeriod', 'type': 'int'},
        'account': {'key': 'account', 'type': 'AccountChildWithType'},
        'meter': {'key': 'meter', 'type': 'MeterChild'},
        'workflow': {'key': 'workflow', 'type': 'ChargebackWorkflowStepChild'},
        'has_bills': {'key': 'hasBills', 'type': 'bool'},
    }

    def __init__(self, version_id=None, version_info=None, chargeback_type=None, begin_period=None, end_period=None, account=None, meter=None, workflow=None, has_bills=None):
        super(DistributionVersionResponse, self).__init__()
        self.version_id = version_id
        self.version_info = version_info
        self.chargeback_type = chargeback_type
        self.begin_period = begin_period
        self.end_period = end_period
        self.account = account
        self.meter = meter
        self.workflow = workflow
        self.has_bills = has_bills



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillReversal(Model):
    """BillReversal.

    :param reference_bill_id: Identifier of the other bill in the reversal
     pair
    :type reference_bill_id: int
    :param reference_type: Indicates whether the reference bill is a reversal
     or source of a reversal.
     It is "Source" if the reference bill is the source bill and "Reversal"
     if the reference bill is the reversal bill
    :type reference_type: str
    :param description: Description of the reversal pair
    :type description: str
    """

    _attribute_map = {
        'reference_bill_id': {'key': 'referenceBillId', 'type': 'int'},
        'reference_type': {'key': 'referenceType', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
    }

    def __init__(self, reference_bill_id=None, reference_type=None, description=None):
        super(BillReversal, self).__init__()
        self.reference_bill_id = reference_bill_id
        self.reference_type = reference_type
        self.description = description



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportMailerChild(Model):
    """ReportMailerChild.

    :param last_sent: The date that the report mailer was last processesd
    :type last_sent: datetime
    :param next_sent: The next time the report mailer will be processed
    :type next_sent: datetime
    :param report_batch:
    :type report_batch: ~energycap.sdk.models.ReportBatchChild
    :param report_emails_sent: Report emails successfully sent to their
     recipient
    :type report_emails_sent: list[~energycap.sdk.models.ReportEmail]
    :param report_emails_not_sent: Report emails not successfully sent to
     their recipients
    :type report_emails_not_sent: list[~energycap.sdk.models.ReportEmail]
    """

    _attribute_map = {
        'last_sent': {'key': 'lastSent', 'type': 'iso-8601'},
        'next_sent': {'key': 'nextSent', 'type': 'iso-8601'},
        'report_batch': {'key': 'reportBatch', 'type': 'ReportBatchChild'},
        'report_emails_sent': {'key': 'reportEmailsSent', 'type': '[ReportEmail]'},
        'report_emails_not_sent': {'key': 'reportEmailsNotSent', 'type': '[ReportEmail]'},
    }

    def __init__(self, last_sent=None, next_sent=None, report_batch=None, report_emails_sent=None, report_emails_not_sent=None):
        super(ReportMailerChild, self).__init__()
        self.last_sent = last_sent
        self.next_sent = next_sent
        self.report_batch = report_batch
        self.report_emails_sent = report_emails_sent
        self.report_emails_not_sent = report_emails_not_sent



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillSplitDetailsRequest(Model):
    """Defines details for available types of bill split distributions. Only one
    of the properties may be populated.

    :param fixed_percentage_split: Populate if setting up a fixed percentage
     split.
     You cannot split to the same account and meter combination multiple times
     within a single version.
     The destination account cannot be the same as the master account <span
     class='property-internal'>Cannot be Empty</span> <span
     class='property-internal'>NULL Valid</span> <span
     class='property-internal'>Required (defined)</span>
    :type fixed_percentage_split: list[~energycap.sdk.models.FixedPercentage]
    :param floor_area_split: Populate if setting up a dynamic percentage split
     based on the building floor area with weighting factor applied.
     You cannot split the same account and meter multiple times within a single
     version.
     You cannot split to the same account and meter combination multiple times
     within a single version.
     The destination account cannot be the same as the master account <span
     class='property-internal'>Cannot be Empty</span> <span
     class='property-internal'>NULL Valid</span> <span
     class='property-internal'>Required (defined)</span>
    :type floor_area_split: list[~energycap.sdk.models.FloorAreaSplit]
    :param dynamic_percentage_split:
    :type dynamic_percentage_split:
     ~energycap.sdk.models.DynamicPercentageBillSplit
    """

    _attribute_map = {
        'fixed_percentage_split': {'key': 'fixedPercentageSplit', 'type': '[FixedPercentage]'},
        'floor_area_split': {'key': 'floorAreaSplit', 'type': '[FloorAreaSplit]'},
        'dynamic_percentage_split': {'key': 'dynamicPercentageSplit', 'type': 'DynamicPercentageBillSplit'},
    }

    def __init__(self, fixed_percentage_split=None, floor_area_split=None, dynamic_percentage_split=None):
        super(BillSplitDetailsRequest, self).__init__()
        self.fixed_percentage_split = fixed_percentage_split
        self.floor_area_split = floor_area_split
        self.dynamic_percentage_split = dynamic_percentage_split



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Claim(Model):
    """Claim.

    :param claim_type: Type of claim
    :type claim_type: str
    :param value: Claim value
    :type value: str
    """

    _attribute_map = {
        'claim_type': {'key': 'claimType', 'type': 'str'},
        'value': {'key': 'value', 'type': 'str'},
    }

    def __init__(self, claim_type=None, value=None):
        super(Claim, self).__init__()
        self.claim_type = claim_type
        self.value = value



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChannelResponse(Model):
    """ChannelResponse.

    :param channel_id: The channel identifier
    :type channel_id: int
    :param channel_code: The channel code
    :type channel_code: str
    :param meter:
    :type meter: ~energycap.sdk.models.MeterChild
    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param observation_type:
    :type observation_type: ~energycap.sdk.models.ObservationTypeChild
    :param observation_method:
    :type observation_method: ~energycap.sdk.models.ObservationMethod
    :param observation_rule:
    :type observation_rule: ~energycap.sdk.models.ObservationRule
    :param unit:
    :type unit: ~energycap.sdk.models.UnitChild
    :param interval_minutes: The interval of the channel. The interval is
     measured in minutes
    :type interval_minutes: int
    :param hidden: Indicates if the channel is hidden
    :type hidden: bool
    :param total_sum: The total sum
    :type total_sum: bool
    :param properties:
    :type properties: ~energycap.sdk.models.DeviceChannelChild
    :param has_readings: Indicates if the channel has readings
    :type has_readings: bool
    :param is_used_on_distribution: Indicates if the channel is a part of a
     distribution
    :type is_used_on_distribution: bool
    :param last_reading_date: Date of the most recent reading for this channel
    :type last_reading_date: datetime
    :param first_reading_date:
    :type first_reading_date: datetime
    :param auto_summarize: Indicates if the channels reading is auto
     summarized
    :type auto_summarize: bool
    :param channel_import_id: The import identifier for the channel.
    :type channel_import_id: str
    :param maximum_reading: The channel's max reading
    :type maximum_reading: float
    :param multiplier: The channel multiplier
    :type multiplier: float
    """

    _attribute_map = {
        'channel_id': {'key': 'channelId', 'type': 'int'},
        'channel_code': {'key': 'channelCode', 'type': 'str'},
        'meter': {'key': 'meter', 'type': 'MeterChild'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'observation_type': {'key': 'observationType', 'type': 'ObservationTypeChild'},
        'observation_method': {'key': 'observationMethod', 'type': 'ObservationMethod'},
        'observation_rule': {'key': 'observationRule', 'type': 'ObservationRule'},
        'unit': {'key': 'unit', 'type': 'UnitChild'},
        'interval_minutes': {'key': 'intervalMinutes', 'type': 'int'},
        'hidden': {'key': 'hidden', 'type': 'bool'},
        'total_sum': {'key': 'totalSum', 'type': 'bool'},
        'properties': {'key': 'properties', 'type': 'DeviceChannelChild'},
        'has_readings': {'key': 'hasReadings', 'type': 'bool'},
        'is_used_on_distribution': {'key': 'isUsedOnDistribution', 'type': 'bool'},
        'last_reading_date': {'key': 'lastReadingDate', 'type': 'iso-8601'},
        'first_reading_date': {'key': 'firstReadingDate', 'type': 'iso-8601'},
        'auto_summarize': {'key': 'autoSummarize', 'type': 'bool'},
        'channel_import_id': {'key': 'channelImportId', 'type': 'str'},
        'maximum_reading': {'key': 'maximumReading', 'type': 'float'},
        'multiplier': {'key': 'multiplier', 'type': 'float'},
    }

    def __init__(self, channel_id=None, channel_code=None, meter=None, commodity=None, observation_type=None, observation_method=None, observation_rule=None, unit=None, interval_minutes=None, hidden=None, total_sum=None, properties=None, has_readings=None, is_used_on_distribution=None, last_reading_date=None, first_reading_date=None, auto_summarize=None, channel_import_id=None, maximum_reading=None, multiplier=None):
        super(ChannelResponse, self).__init__()
        self.channel_id = channel_id
        self.channel_code = channel_code
        self.meter = meter
        self.commodity = commodity
        self.observation_type = observation_type
        self.observation_method = observation_method
        self.observation_rule = observation_rule
        self.unit = unit
        self.interval_minutes = interval_minutes
        self.hidden = hidden
        self.total_sum = total_sum
        self.properties = properties
        self.has_readings = has_readings
        self.is_used_on_distribution = is_used_on_distribution
        self.last_reading_date = last_reading_date
        self.first_reading_date = first_reading_date
        self.auto_summarize = auto_summarize
        self.channel_import_id = channel_import_id
        self.maximum_reading = maximum_reading
        self.multiplier = multiplier



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ListTypeChild(Model):
    """ListTypeChild.

    :param list_type_id:
    :type list_type_id: int
    :param list_type_info:
    :type list_type_info: str
    :param list_type_description:
    :type list_type_description: str
    """

    _attribute_map = {
        'list_type_id': {'key': 'listTypeId', 'type': 'int'},
        'list_type_info': {'key': 'listTypeInfo', 'type': 'str'},
        'list_type_description': {'key': 'listTypeDescription', 'type': 'str'},
    }

    def __init__(self, list_type_id=None, list_type_info=None, list_type_description=None):
        super(ListTypeChild, self).__init__()
        self.list_type_id = list_type_id
        self.list_type_info = list_type_info
        self.list_type_description = list_type_description



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterGroupDigestRankingResponse(Model):
    """MeterGroupDigestRankingResponse.

    :param high_cost:
    :type high_cost: float
    :param low_cost:
    :type low_cost: float
    :param average_cost:
    :type average_cost: float
    :param median_cost:
    :type median_cost: float
    :param high_use:
    :type high_use: float
    :param low_use:
    :type low_use: float
    :param average_use:
    :type average_use: float
    :param median_use:
    :type median_use: float
    :param high_unit_cost:
    :type high_unit_cost: float
    :param low_unit_cost:
    :type low_unit_cost: float
    :param average_unit_cost:
    :type average_unit_cost: float
    :param median_unit_cost:
    :type median_unit_cost: float
    :param high_value:
    :type high_value: float
    :param low_value:
    :type low_value: float
    :param average_value:
    :type average_value: float
    :param median_value:
    :type median_value: float
    :param cost_unit:
    :type cost_unit: ~energycap.sdk.models.UnitChild
    :param use_unit:
    :type use_unit: ~energycap.sdk.models.UnitChild
    :param benchmark_unit:
    :type benchmark_unit: str
    :param benchmark_value_unit:
    :type benchmark_value_unit: str
    :param benchmark_factor_unit:
    :type benchmark_factor_unit: str
    :param high_savings_opportunity:
    :type high_savings_opportunity: float
    :param results:
    :type results: list[~energycap.sdk.models.MeterGroupDigestRankingChild]
    :param meter_group_id:
    :type meter_group_id: int
    :param meter_group_code:
    :type meter_group_code: str
    :param meter_group_info:
    :type meter_group_info: str
    :param meter_group_display:
    :type meter_group_display: str
    :param updated: The date and time the data was updated
    :type updated: datetime
    """

    _attribute_map = {
        'high_cost': {'key': 'highCost', 'type': 'float'},
        'low_cost': {'key': 'lowCost', 'type': 'float'},
        'average_cost': {'key': 'averageCost', 'type': 'float'},
        'median_cost': {'key': 'medianCost', 'type': 'float'},
        'high_use': {'key': 'highUse', 'type': 'float'},
        'low_use': {'key': 'lowUse', 'type': 'float'},
        'average_use': {'key': 'averageUse', 'type': 'float'},
        'median_use': {'key': 'medianUse', 'type': 'float'},
        'high_unit_cost': {'key': 'highUnitCost', 'type': 'float'},
        'low_unit_cost': {'key': 'lowUnitCost', 'type': 'float'},
        'average_unit_cost': {'key': 'averageUnitCost', 'type': 'float'},
        'median_unit_cost': {'key': 'medianUnitCost', 'type': 'float'},
        'high_value': {'key': 'highValue', 'type': 'float'},
        'low_value': {'key': 'lowValue', 'type': 'float'},
        'average_value': {'key': 'averageValue', 'type': 'float'},
        'median_value': {'key': 'medianValue', 'type': 'float'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
        'use_unit': {'key': 'useUnit', 'type': 'UnitChild'},
        'benchmark_unit': {'key': 'benchmarkUnit', 'type': 'str'},
        'benchmark_value_unit': {'key': 'benchmarkValueUnit', 'type': 'str'},
        'benchmark_factor_unit': {'key': 'benchmarkFactorUnit', 'type': 'str'},
        'high_savings_opportunity': {'key': 'highSavingsOpportunity', 'type': 'float'},
        'results': {'key': 'results', 'type': '[MeterGroupDigestRankingChild]'},
        'meter_group_id': {'key': 'meterGroupId', 'type': 'int'},
        'meter_group_code': {'key': 'meterGroupCode', 'type': 'str'},
        'meter_group_info': {'key': 'meterGroupInfo', 'type': 'str'},
        'meter_group_display': {'key': 'meterGroupDisplay', 'type': 'str'},
        'updated': {'key': 'updated', 'type': 'iso-8601'},
    }

    def __init__(self, high_cost=None, low_cost=None, average_cost=None, median_cost=None, high_use=None, low_use=None, average_use=None, median_use=None, high_unit_cost=None, low_unit_cost=None, average_unit_cost=None, median_unit_cost=None, high_value=None, low_value=None, average_value=None, median_value=None, cost_unit=None, use_unit=None, benchmark_unit=None, benchmark_value_unit=None, benchmark_factor_unit=None, high_savings_opportunity=None, results=None, meter_group_id=None, meter_group_code=None, meter_group_info=None, meter_group_display=None, updated=None):
        super(MeterGroupDigestRankingResponse, self).__init__()
        self.high_cost = high_cost
        self.low_cost = low_cost
        self.average_cost = average_cost
        self.median_cost = median_cost
        self.high_use = high_use
        self.low_use = low_use
        self.average_use = average_use
        self.median_use = median_use
        self.high_unit_cost = high_unit_cost
        self.low_unit_cost = low_unit_cost
        self.average_unit_cost = average_unit_cost
        self.median_unit_cost = median_unit_cost
        self.high_value = high_value
        self.low_value = low_value
        self.average_value = average_value
        self.median_value = median_value
        self.cost_unit = cost_unit
        self.use_unit = use_unit
        self.benchmark_unit = benchmark_unit
        self.benchmark_value_unit = benchmark_value_unit
        self.benchmark_factor_unit = benchmark_factor_unit
        self.high_savings_opportunity = high_savings_opportunity
        self.results = results
        self.meter_group_id = meter_group_id
        self.meter_group_code = meter_group_code
        self.meter_group_info = meter_group_info
        self.meter_group_display = meter_group_display
        self.updated = updated



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterTemplateResponse(Model):
    """MeterTemplateResponse.

    :param form_template_id: The form template identifier
    :type form_template_id: int
    :param display_order: The meter template display order
    :type display_order: int
    :param begin_date: The begin date for the template on the account meter
    :type begin_date: datetime
    :param end_date: The end date for the template on the account meter
    :type end_date: datetime
    :param template:
    :type template: ~energycap.sdk.models.TemplateChild
    :param account:
    :type account: ~energycap.sdk.models.MeterAccountChild
    """

    _attribute_map = {
        'form_template_id': {'key': 'formTemplateId', 'type': 'int'},
        'display_order': {'key': 'displayOrder', 'type': 'int'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'template': {'key': 'template', 'type': 'TemplateChild'},
        'account': {'key': 'account', 'type': 'MeterAccountChild'},
    }

    def __init__(self, form_template_id=None, display_order=None, begin_date=None, end_date=None, template=None, account=None):
        super(MeterTemplateResponse, self).__init__()
        self.form_template_id = form_template_id
        self.display_order = display_order
        self.begin_date = begin_date
        self.end_date = end_date
        self.template = template
        self.account = account



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GeneralLedgerRequest(Model):
    """GeneralLedgerRequest.

    :param general_ledger_code: Unique identifier for the General Ledger <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type general_ledger_code: str
    :param sub_codes: List of 20 sub codes and their values <span
     class='property-internal'>Required</span>
    :type sub_codes: list[~energycap.sdk.models.GLSubCodeChildRequest]
    """

    _validation = {
        'general_ledger_code': {'required': True, 'max_length': 255, 'min_length': 0},
        'sub_codes': {'required': True},
    }

    _attribute_map = {
        'general_ledger_code': {'key': 'generalLedgerCode', 'type': 'str'},
        'sub_codes': {'key': 'subCodes', 'type': '[GLSubCodeChildRequest]'},
    }

    def __init__(self, general_ledger_code, sub_codes):
        super(GeneralLedgerRequest, self).__init__()
        self.general_ledger_code = general_ledger_code
        self.sub_codes = sub_codes



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillEntryBodyLine(Model):
    """BillEntryBodyLine.

    :param body_line_id: The body line identifier
    :type body_line_id: int
    :param caption: The body line's caption
    :type caption: str
    :param value:
    :type value: ~energycap.sdk.models.BillEntryBodyLineWithNounChild
    :param cost:
    :type cost: ~energycap.sdk.models.BillEntryBodyLineChild
    :param observation_type:
    :type observation_type:
     ~energycap.sdk.models.BillEntryObservationTypeChild
    """

    _attribute_map = {
        'body_line_id': {'key': 'bodyLineId', 'type': 'int'},
        'caption': {'key': 'caption', 'type': 'str'},
        'value': {'key': 'value', 'type': 'BillEntryBodyLineWithNounChild'},
        'cost': {'key': 'cost', 'type': 'BillEntryBodyLineChild'},
        'observation_type': {'key': 'observationType', 'type': 'BillEntryObservationTypeChild'},
    }

    def __init__(self, body_line_id=None, caption=None, value=None, cost=None, observation_type=None):
        super(BillEntryBodyLine, self).__init__()
        self.body_line_id = body_line_id
        self.caption = caption
        self.value = value
        self.cost = cost
        self.observation_type = observation_type



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RateEdit(Model):
    """RateEdit.

    :param name:  <span class='property-internal'>Must be between 0 and 255
     characters</span> <span class='property-internal'>Required
     (defined)</span>
    :type name: str
    :param note:  <span class='property-internal'>Must be between 0 and 255
     characters</span> <span class='property-internal'>Required
     (defined)</span>
    :type note: str
    """

    _validation = {
        'name': {'max_length': 255, 'min_length': 0},
        'note': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'note': {'key': 'note', 'type': 'str'},
    }

    def __init__(self, name=None, note=None):
        super(RateEdit, self).__init__()
        self.name = name
        self.note = note



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterRateResponse(Model):
    """MeterRateResponse.

    :param rate_id: The meter tariff identifier
    :type rate_id: int
    :param name: The rate name
    :type name: str
    :param rate_code: The rate code
    :type rate_code: str
    :param start_date: The start date for the rate on the account meter
    :type start_date: datetime
    :param end_date: The end date for the rate on the account meter
    :type end_date: datetime
    :param account:
    :type account: ~energycap.sdk.models.MeterAccountChild
    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param note: The rate's note
    :type note: str
    """

    _attribute_map = {
        'rate_id': {'key': 'rateId', 'type': 'int'},
        'name': {'key': 'name', 'type': 'str'},
        'rate_code': {'key': 'rateCode', 'type': 'str'},
        'start_date': {'key': 'startDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'account': {'key': 'account', 'type': 'MeterAccountChild'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'note': {'key': 'note', 'type': 'str'},
    }

    def __init__(self, rate_id=None, name=None, rate_code=None, start_date=None, end_date=None, account=None, commodity=None, note=None):
        super(MeterRateResponse, self).__init__()
        self.rate_id = rate_id
        self.name = name
        self.rate_code = rate_code
        self.start_date = start_date
        self.end_date = end_date
        self.account = account
        self.commodity = commodity
        self.note = note



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountCodeHistoryResponse(Model):
    """AccountCodeHistoryResponse.

    :param account_id: Account identifier <span
     class='property-internal'>Required (defined)</span>
    :type account_id: int
    :param account_code: Account code of the account <span
     class='property-internal'>Required (defined)</span>
    :type account_code: str
    :param account_info: Name of the account <span
     class='property-internal'>Required (defined)</span>
    :type account_info: str
    :param account_code_history:
    :type account_code_history: ~energycap.sdk.models.AccountCodeHistoryChild
    """

    _attribute_map = {
        'account_id': {'key': 'accountId', 'type': 'int'},
        'account_code': {'key': 'accountCode', 'type': 'str'},
        'account_info': {'key': 'accountInfo', 'type': 'str'},
        'account_code_history': {'key': 'accountCodeHistory', 'type': 'AccountCodeHistoryChild'},
    }

    def __init__(self, account_id=None, account_code=None, account_info=None, account_code_history=None):
        super(AccountCodeHistoryResponse, self).__init__()
        self.account_id = account_id
        self.account_code = account_code
        self.account_info = account_info
        self.account_code_history = account_code_history



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GLSubcodeResponse(Model):
    """GLSubcodeResponse.

    :param sub_code_index: Index of this subcode (01-20)
    :type sub_code_index: str
    :param sub_code_name: Name for this SubCode
    :type sub_code_name: str
    :param sub_code_type: SubCodeType - will be "list"(if fixed=1 in DB) or
     "text" (if fixed=0) in DB
    :type sub_code_type: str
    :param sub_code_values: An array of pick list values when this subcode is
     a "list"
    :type sub_code_values: list[str]
    """

    _attribute_map = {
        'sub_code_index': {'key': 'subCodeIndex', 'type': 'str'},
        'sub_code_name': {'key': 'subCodeName', 'type': 'str'},
        'sub_code_type': {'key': 'subCodeType', 'type': 'str'},
        'sub_code_values': {'key': 'subCodeValues', 'type': '[str]'},
    }

    def __init__(self, sub_code_index=None, sub_code_name=None, sub_code_type=None, sub_code_values=None):
        super(GLSubcodeResponse, self).__init__()
        self.sub_code_index = sub_code_index
        self.sub_code_name = sub_code_name
        self.sub_code_type = sub_code_type
        self.sub_code_values = sub_code_values



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class LicenseRequest(Model):
    """LicenseRequest.

    :param validation_key: User's license validation key. <span
     class='property-internal'>Required (defined)</span>
    :type validation_key: str
    """

    _attribute_map = {
        'validation_key': {'key': 'validationKey', 'type': 'str'},
    }

    def __init__(self, validation_key=None):
        super(LicenseRequest, self).__init__()
        self.validation_key = validation_key



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceSizeCreate(Model):
    """PlaceSizeCreate.

    :param begin_date: The begin date for the place size <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Required</span>
    :type begin_date: datetime
    :param value: The place size value <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 2147483647</span> <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 2147483647</span>
    :type value: int
    :param unit_code: <p>The place size's unit code</p>
     <p>Options are SQFEET for Square Feet and SQMETER for Square Meters</p>
     <span class='property-internal'>One of SQFEET, SQMETER </span> <span
     class='property-internal'>Must be between 0 and 16 characters</span> <span
     class='property-internal'>One of SQFEET, SQMETER </span> <span
     class='property-internal'>Must be between 0 and 16 characters</span> <span
     class='property-internal'>Required (defined)</span>
    :type unit_code: str
    """

    _validation = {
        'begin_date': {'required': True},
        'value': {'required': True, 'maximum': 2147483647, 'minimum': 0},
        'unit_code': {'max_length': 16, 'min_length': 0},
    }

    _attribute_map = {
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'value': {'key': 'value', 'type': 'int'},
        'unit_code': {'key': 'unitCode', 'type': 'str'},
    }

    def __init__(self, begin_date, value, unit_code=None):
        super(PlaceSizeCreate, self).__init__()
        self.begin_date = begin_date
        self.value = value
        self.unit_code = unit_code



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WebhookEventTypeChild(Model):
    """WebhookEventTypeChild.

    :param webhook_event_type_id: The identifier for the webhook event type
    :type webhook_event_type_id: int
    :param webhook_event_type_name: The name of the webhook event type
    :type webhook_event_type_name: str
    """

    _attribute_map = {
        'webhook_event_type_id': {'key': 'webhookEventTypeId', 'type': 'int'},
        'webhook_event_type_name': {'key': 'webhookEventTypeName', 'type': 'str'},
    }

    def __init__(self, webhook_event_type_id=None, webhook_event_type_name=None):
        super(WebhookEventTypeChild, self).__init__()
        self.webhook_event_type_id = webhook_event_type_id
        self.webhook_event_type_name = webhook_event_type_name



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WebhookLogResponse(Model):
    """WebhookLogResponse.

    :param webhook_log_id: The identifier of the webhook log
    :type webhook_log_id: long
    :param request_timestamp: The date and time that the webhook was fired
    :type request_timestamp: datetime
    :param result: The HTTP status code that was received from the configured
     url
     0 indicates no response was received from the configured url
    :type result: str
    :param user:
    :type user: ~energycap.sdk.models.UserChild
    """

    _attribute_map = {
        'webhook_log_id': {'key': 'webhookLogId', 'type': 'long'},
        'request_timestamp': {'key': 'requestTimestamp', 'type': 'iso-8601'},
        'result': {'key': 'result', 'type': 'str'},
        'user': {'key': 'user', 'type': 'UserChild'},
    }

    def __init__(self, webhook_log_id=None, request_timestamp=None, result=None, user=None):
        super(WebhookLogResponse, self).__init__()
        self.webhook_log_id = webhook_log_id
        self.request_timestamp = request_timestamp
        self.result = result
        self.user = user



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MapPlace(Model):
    """MapPlace.

    :param place_id: The identifier for place
    :type place_id: int
    :param place_code: The place code
    :type place_code: str
    :param place_info: The place information
    :type place_info: str
    :param address:
    :type address: ~energycap.sdk.models.AddressChild
    """

    _attribute_map = {
        'place_id': {'key': 'placeId', 'type': 'int'},
        'place_code': {'key': 'placeCode', 'type': 'str'},
        'place_info': {'key': 'placeInfo', 'type': 'str'},
        'address': {'key': 'address', 'type': 'AddressChild'},
    }

    def __init__(self, place_id=None, place_code=None, place_info=None, address=None):
        super(MapPlace, self).__init__()
        self.place_id = place_id
        self.place_code = place_code
        self.place_info = place_info
        self.address = address
